<?php
/**
 * The email validator
 *
 * @package BPMVP/API
 */

/**
 * Class BPMVP_Phone_Validator
 */
class BPMVP_Phone_Validator {

	/**
	 * Whether the number is valid.
	 *
	 * @var bool
	 */
	protected $is_valid = TRUE;

	/**
	 * The email to validate.
	 *
	 * @var string
	 */
	protected $email = '';


	/**
	 * The phone number status.
	 *
	 * @var string
	 */
	protected $email_status = '';

	/**
	 * The API object.
	 *
	 * @var object
	 */
	protected $api = NULL;

	/**
	 * Validate the email address.
	 *
	 * @return boolean
	 */
	public function validate() {

		$api = $this->get_api();
		$api->set_email( $this->get_email() );
		$response = $api->request();
		if ( ! empty( $response->status ) ) {
			$this->set_email_status( $response->status );
		}

		$this->set_is_valid( TRUE );

		// If there was an connection error, the phone number is valid.
		if ( NULL === $response ) {
			$this->set_is_valid( TRUE );

			/**
			 * Filters whether the phone number is valid.
			 *
			 * @param boolean $is_valid Whether the email is valid or not.
			 * @param object  $response The response
			 */
			return apply_filters( 'bpmvp_email_valid', $this->get_is_valid(), $response );
		}

		$valid_statuse = array(
			'200',
			'207',
			'215',
			'119',
		);

		if ( ! in_array( $this->get_email_status(), $valid_statuse, TRUE ) ) {
			$this->set_is_valid( FALSE );
		}

		// If the API Key is invalid or depleted, we update an option to show an admin notice.
		if ( '119' === $this->get_email_status() ) {
			update_option( 'bpmvp-api-key-invalid', 1 );
		}

		/**
		 * Filters whether the phone number is valid.
		 *
		 * @param boolean $is_valid Whether the email is valid or not.
		 * @param object  $response The response
		 */
		return apply_filters( 'bpmvp_email_valid', $this->get_is_valid(), $response );
	}

	/**
	 * Get the validty of a number.
	 *
	 * @return bool
	 */
	public function get_is_valid() {

		return $this->is_valid;
	}

	/**
	 * Set the validty of a number.
	 *
	 * @param bool $is_valid The validity.
	 *
	 * @return bool
	 */
	protected function set_is_valid( $is_valid ) {

		$this->is_valid = (bool) $is_valid;
		return $this->get_is_valid();
	}

	/**
	 * Get the phone number.
	 *
	 * @return string
	 */
	public function get_email() {

		return $this->email;
	}

	/**
	 * Set the phone number.
	 *
	 * @param string $email The phone number.
	 *
	 * @return string
	 */
	public function set_email( $email ) {

		$this->email = (string) $email;
		return $this->get_email();
	}

	/**
	 * Set the phone status.
	 *
	 * @param string $status The status.
	 *
	 * @return string
	 */
	public function set_email_status( $status ) {

		$this->email_status = (string) $status;
		return $this->get_email_status();
	}

	/**
	 * Get the phone status.
	 *
	 * @return string
	 */
	public function get_email_status() {

		return $this->email_status;
	}

	/**
	 * Get the API
	 *
	 * @return object
	 */
	public function get_api() {

		return $this->api;
	}

	/**
	 * Set the API.
	 *
	 * @param object $api The API Object.
	 *
	 * @return object
	 */
	public function set_api( $api ) {

		$this->api = (object) $api;
		return $this->get_api();
	}
}
